==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/ro.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Activitate recentă personală pentru %s",
    "Your feed URL is invalid" : "Adresa URL a fluxului este greșită",
    "Activity feed for %1$s" : "Flux de activitate pentru %1$s",
    "Activity feed" : "Flux de Activitate",
    "Your settings have been updated." : "Setările dvs. au fost actualizate.",
    "Settings have been updated." : "Setările au fost actualizate.",
    "Recent activity" : "Activitate recentă",
    "No activities" : "Fără activități",
    "More activities" : "Mai multe acțiuni",
    "Daily activity summary for %s" : "Sumar activitate zilnică pentru %s",
    "All activities" : "Toate activitățile",
    "By others" : "De către alții",
    "By you" : "De către tine",
    "Activity at %s" : "Activitate la %s",
    "Hello %s" : "Salut %s",
    "Hello %s," : "Salut %s,",
    "There was some activity at %s" : "A fost activitate la %s",
    "_and %n more _::_and %n more _" : ["și încă %n","și încă %n","și încă %n"],
    "Mail" : "Mail",
    "Push" : "Push",
    "Activity" : "Activitate",
    "Notifications" : "Notificări",
    "This application enables people to view a log of activities about them, their files or other data." : "Această aplicație le permite oamenilor să vadă un jurnal de activități despre ei, fișierele lor sau alte date.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Această aplicație permite oamenilor să vadă acțiuni legate de fișierele și datele lor în Nextcloud.\nFiecare persoană își poate configura setările individuale de activitate în setările personale,\npentru a alege ce activitații trebuie să fie transmise pe telefon mobil sau prin e-mail\nsau dacă un rezumat zilnic este trimis în fiecare dimineață.\nMai multe informații sunt disponibile în documentația activității.",
    "Send email" : "Trimite email",
    "Send push notification" : "Trimite notificare push",
    "Activity notification configuration" : "Configurația notificărilor de activitate",
    "Today" : "Astăzi",
    "Yesterday" : "Ieri",
    "You need to set up your email address before you can receive notification emails." : "Trebuie să-ți configurezi adresa de email înainte de a putea primi emailurile de notificare.",
    "Send activity emails" : "Trimitere email-uri cu activitate",
    "As soon as possible" : "Cât mai curând posibil",
    "Hourly" : "La oră",
    "Daily" : "Zilnic",
    "Weekly" : "Săptămânal",
    "You commented" : "Ai comentat",
    "Message deleted by author" : "Mesaj șters de autor",
    "Open {filename}" : "Deschide {filename}",
    "in {path}" : "în {path}",
    "Home" : "Acasă",
    "Could not load activities" : "Nu s-au putut încărca activitățile",
    "Loading activities" : "Se încarcă activitățile",
    "This stream will show events like additions, changes & shares" : "Acest flux va afișa evenimente ca adăugiri, modificări & partajări",
    "No activity yet" : "Nicio activitate încă.",
    "Loading more activities" : "Se încarcă mai multe activități",
    "No more activities." : "Nu mai sunt alte activități.",
    "Could not enable RSS link" : "Nu s-a putut activa linkul RSS",
    "RSS link copied to clipboard" : "Linkul RSS a fost copiat ",
    "Could not copy the RSS link, please copy manually:" : "Nu s-a putut copia linkul RSS, copiați manual:",
    "Activity settings" : "Setări ale activității",
    "Enable RSS feed" : "Activați flux RSS",
    "RSS feed" : "Flux RSS",
    "Copy RSS feed link" : "Copie legatura fluxului RSS",
    "Personal notification settings" : "Setări personale de notificare",
    "Unable to load the activity list" : "Lista de activități nu poate fi încărcată",
    "Choose for which activities you want to get an email or push notification." : "Alege pentru care activități vrei sa primești notificare pe e-mail sau de tip push.",
    "Choose for which activities you want to get a push notification." : "Alege pentru care activități vrei sa primești notificare de tip push.",
    "Notification" : "Notificări",
    "Enable notification emails" : "Activează notificările pe e-mail",
    "Daily activity summary" : "Sumar activitate zilnică",
    "Send daily activity summary in the morning" : "Trimite sumarul zilnic de activitate dimineața ",
    "Default settings" : "Setări implicite",
    "Configure the default notification settings for new accounts." : "Configurați setările implicite de notificare pentru conturile noi.",
    "Unable to save the settings" : "Nu se pot salva setările",
    "No more events to load" : "Nu mai sunt evenimente de încărcat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/ro.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Activitate recentă personală pentru %s",
    "Your feed URL is invalid" : "Adresa URL a fluxului este greșită",
    "Activity feed for %1$s" : "Flux de activitate pentru %1$s",
    "Activity feed" : "Flux de Activitate",
    "Your settings have been updated." : "Setările dvs. au fost actualizate.",
    "Settings have been updated." : "Setările au fost actualizate.",
    "remote user" : "utilizator",
    "Recent activity" : "Activitate recentă",
    "No activities" : "Fără activități",
    "More activities" : "Mai multe acțiuni",
    "Daily activity summary for %s" : "Sumar activitate zilnică pentru %s",
    "All activities" : "Toate activitățile",
    "By others" : "De către alții",
    "By you" : "De către tine",
    "Activity at %s" : "Activitate la %s",
    "Hello %s" : "Salut %s",
    "Hello %s," : "Salut %s,",
    "There was some activity at %s" : "A fost activitate la %s",
    "_and %n more _::_and %n more _" : ["și încă %n","și încă %n","și încă %n"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puteți schimba frecvența acestor emailuri sau să le dezactivați din <a href=\"%s\">setări</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Puteți schimba frecvența acestor emailuri sau să le dezactivați din setări: %s",
    "Mail" : "Mail",
    "Push" : "Push",
    "Activity" : "Activitate",
    "Notifications" : "Notificări",
    "This application enables people to view a log of activities about them, their files or other data." : "Această aplicație le permite oamenilor să vadă un jurnal de activități despre ei, fișierele lor sau alte date.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Această aplicație permite oamenilor să vadă acțiuni legate de fișierele și datele lor în Nextcloud.\nFiecare persoană își poate configura setările individuale de activitate în setările personale,\npentru a alege ce activitații trebuie să fie transmise pe telefon mobil sau prin e-mail\nsau dacă un rezumat zilnic este trimis în fiecare dimineață.\nMai multe informații sunt disponibile în documentația activității.",
    "Send email" : "Trimite email",
    "Send push notification" : "Trimite notificare push",
    "Activity notification configuration" : "Configurația notificărilor de activitate",
    "Today" : "Astăzi",
    "Yesterday" : "Ieri",
    "You need to set up your email address before you can receive notification emails." : "Trebuie să-ți configurezi adresa de email înainte de a putea primi emailurile de notificare.",
    "Send activity emails" : "Trimitere email-uri cu activitate",
    "As soon as possible" : "Cât mai curând posibil",
    "Hourly" : "La oră",
    "Daily" : "Zilnic",
    "Weekly" : "Săptămânal",
    "You commented" : "Ai comentat",
    "Message deleted by author" : "Mesaj șters de autor",
    "Open {filename}" : "Deschide {filename}",
    "in {path}" : "în {path}",
    "Home" : "Acasă",
    "Could not load activities" : "Nu s-au putut încărca activitățile",
    "Loading activities" : "Se încarcă activitățile",
    "This stream will show events like additions, changes & shares" : "Acest flux va afișa evenimente ca adăugiri, modificări & partajări",
    "No activity yet" : "Nicio activitate încă.",
    "Loading more activities" : "Se încarcă mai multe activități",
    "No more activities." : "Nu mai sunt alte activități.",
    "Could not enable RSS link" : "Nu s-a putut activa linkul RSS",
    "RSS link copied to clipboard" : "Linkul RSS a fost copiat ",
    "Could not copy the RSS link, please copy manually:" : "Nu s-a putut copia linkul RSS, copiați manual:",
    "Activity settings" : "Setări ale activității",
    "Enable RSS feed" : "Activați flux RSS",
    "RSS feed" : "Flux RSS",
    "Copy RSS feed link" : "Copie legatura fluxului RSS",
    "Personal notification settings" : "Setări personale de notificare",
    "Unable to load the activity list" : "Lista de activități nu poate fi încărcată",
    "Choose for which activities you want to get an email or push notification." : "Alege pentru care activități vrei sa primești notificare pe e-mail sau de tip push.",
    "Choose for which activities you want to get a push notification." : "Alege pentru care activități vrei sa primești notificare de tip push.",
    "Notification" : "Notificări",
    "Enable notification emails" : "Activează notificările pe e-mail",
    "Daily activity summary" : "Sumar activitate zilnică",
    "Send daily activity summary in the morning" : "Trimite sumarul zilnic de activitate dimineața ",
    "Default settings" : "Setări implicite",
    "Configure the default notification settings for new accounts." : "Configurați setările implicite de notificare pentru conturile noi.",
    "Unable to save the settings" : "Nu se pot salva setările",
    "No more events to load" : "Nu mai sunt evenimente de încărcat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
